# satellite_tools

A brief description of your package. (e.g., "A Python module for scientific data analysis.")
A Python module for download and analysis the satellite dataset.

## Installation

```bash
pip install satellite_tools

